
/* 
 * Simulated beta spectrum for various B-field settings with 
 * experimental background spectrum superimposed.
 */

void BetaSpec(double hours = 1, double rate = 30E3, int binWidth = 25, double ROImin = 1500, double ROImax = 7000)
{
    Double_t seconds = hours*3600;

    const double emin = 0;
    const double emax = 8E3;
    const int bins = (emax - emin) / binWidth;

    vector<int> bmax = {10, 20, 30, 40, 44, 46, 48, 50};

    // canvas
    TCanvas * c1 = new TCanvas("c1");


    // ----------- background measurement --------------- //
    TString datadir = "/home/oliskir/Desktop/f20/data/sorted/new/";
    double backgrHours = 11.5;
    // add files
    TChain * chain = new TChain("data");    
    chain->Add(datadir+"*0311*");    
    // histogram
    TH1F * hbackgr = new TH1F("backgr", "backgr", bins, emin, emax);
    // draw
    chain->Draw("E0>>backgr", "Z0 != 10");
    // scaling factor
    hbackgr->Scale(hours/backgrHours);
    // ----------- background measurement --------------- //

        
    int i = 0;
    for (auto& b : bmax) {

        TString fname = Form("b%i/allowed_bmax%i_res.root", b, 100*b);
        TString hname = Form("h%i", b);

        cout << " Input: " << fname << endl;

        TFile * f = new TFile(fname, "READ");
        TTree * t = (TTree*)f->Get("Detector");

        // histograms
        TH1F * h = new TH1F(hname, hname, bins, emin, emax);

        // draw
        t->Draw("EDepSignal>>"+hname, "EDepSignal > 100");

        // scaling factor
        double norm = ((TParameter<double>*)(t->GetUserInfo()->FindObject("NORMALIZATION")))->GetVal();         
        double x = rate * seconds / norm;
        
        // scale
        h->Scale(x);        

        // draw
        h->SetMaximum(5*h->GetMaximum());
        h->SetLineColor(4);
        h->Draw("hist");
        
        hbackgr->SetLineColor(2);
        hbackgr->SetLineStyle(2);
        hbackgr->Draw("histsame");

        // make pretty
        h->SetTitle(Form("1 hour at 30 kHz rate and B_{max} = %.2f T", 0.01*(double)b));
        h->SetMinimum(0.5);
        int binx1 = h->GetXaxis()->FindBin(ROImin);
        int binx2 = h->GetXaxis()->FindBin(ROImax);
        double y = h->Integral(binx1, binx2);
        h->GetXaxis()->SetTitle("Energy (keV)");        
        h->GetYaxis()->SetTitle(Form("Counts / %i keV", binWidth)); 

        double ybackgr = hbackgr->Integral(binx1, binx2);
        
        double yt = 0.3*h->GetMaximum(); 
        TText *tx = new TText(4000, yt, Form("Counts/min %.1f-%.1f MeV: %.1E", ROImin/1000, ROImax/1000, (y+ybackgr)/60.));
        tx->SetTextAlign(11);
        tx->SetTextColor(1);
        tx->SetTextFont(43);
        tx->SetTextSize(16);
        tx->Draw("same");
        
        cout << " B_max:  " << 0.01*b << " T" << endl;
        cout << Form(" Counts %.0f-%.0f keV:  %.0f", ROImin, ROImax, y) << endl;
        cout << " Scaling factor:  " << x << endl;

        gPad->SetLogy();
        gPad->SetGrid();
        gPad->Update();
        gStyle->SetOptStat("");
        
	    Double_t xl1=.7, yl1=0.5, xl2=xl1+0.18, yl2=yl1+0.11;
        TLegend * leg = new TLegend(xl1, yl1, xl2, yl2);
        leg -> AddEntry(h, "^{20}F #beta spectrum", "l");  
        leg -> AddEntry(hbackgr, "Background", "l");  
        leg -> SetTextSize(15);
        leg -> SetTextFont(133);
        leg -> Draw("same");            

        c1->Print(Form("/home/oliskir/Desktop/specs/f20spec_bmax%i.png", 100*b));
 
        cin.get();
        i++;
    }
}
